﻿using System;
using System.Collections.Generic;
using System.Text;
using Senparc.Weixin;
using Senparc.Weixin.TenPay;
using Senparc.Weixin.TenPay.V3;
using Newtonsoft.Json;

namespace WxPayAPI
{
    public class NativePay
    {
        /// <summary>
        /// nlog日志
        /// </summary>
        private static NLog.Logger Log = NLog.LogManager.GetCurrentClassLogger();
        /**
        * 生成扫描支付模式一URL
        * @param productId 商品ID
        * @return 模式一URL
        */
        public string GetPrePayUrl(string productId)
        {
            Log.Info(this.GetType().ToString(), "Native pay mode 1 url is producing...");

            WxPayData data = new WxPayData();
            data.SetValue("appid", WxPayConfig.APPID);//公众帐号id
            data.SetValue("mch_id", WxPayConfig.MCHID);//商户号
            data.SetValue("time_stamp", WxPayApi.GenerateTimeStamp());//时间戳
            data.SetValue("nonce_str", WxPayApi.GenerateNonceStr());//随机字符串
            data.SetValue("product_id", productId);//商品ID
            data.SetValue("sign", data.MakeSign());//签名
            string str = ToUrlParams(data.GetValues());//转换为URL串
            string url = "weixin://wxpay/bizpayurl?" + str;

            Log.Info(this.GetType().ToString(), "Get native pay mode 1 url : " + url);
            return url;
        }



        /// <summary>
        /// 生成直接支付url，支付url有效期为2小时,模式二
        /// </summary>
        /// <param name="productId">商品ID</param>
        /// <param name="total_fee">订单金额，单位为分，类型为整数</param>
        /// <param name="out_trade_no">从商户传来的订单号</param>
        /// <returns>模式二URL</returns>
        public string GetPayUrl(string productId, int total_fee, string out_trade_no)
        {
            Log.Info(this.GetType().ToString() + "-GetPayUrl");

            WxPayData data = new WxPayData();


            data.SetValue("body", "缴费");//商品描述
            data.SetValue("attach", "缴费");//附加数据
            //data.SetValue("out_trade_no", WxPayApi.GenerateOutTradeNo());//随机字符串
            data.SetValue("out_trade_no", out_trade_no);//商户订单号
            data.SetValue("total_fee", total_fee);//总金额
            //data.SetValue("spbill_create_ip", WxPayConfig.IP);//终端IP
            data.SetValue("time_start", DateTime.Now.ToString("yyyyMMddHHmmss"));//交易起始时间
            data.SetValue("time_expire", DateTime.Now.AddMinutes(10).ToString("yyyyMMddHHmmss"));//交易结束时间
            //data.SetValue("notify_url", WxPayConfig.NOTIFY_URL);//通知地址
            data.SetValue("goods_tag", "jjj");//商品标记
            data.SetValue("trade_type", "NATIVE");//交易类型
            data.SetValue("product_id", productId);//商品ID
            //data.SetValue("sign", data.MakeSign());//签名
            Log.Info($"【GetPayUrl】data组装:{JsonConvert.SerializeObject(data)}");
            WxPayData result = WxPayApi.UnifiedOrder(data);//调用统一下单接口
            Log.Info($"【GetPayUrl】调用统一下单接口 result:{JsonConvert.SerializeObject(result)}");
            string url = result.GetValue("code_url") == null ? "" : result.GetValue("code_url").ToString();//获得统一下单接口返回的二维码链接

            //Log.Info(this.GetType().ToString(), "Get native pay mode 2 url : " + url);
            return url;
        }
        /// <summary>
        /// 新闻查看支付获取url
        /// </summary>
        /// <param name="productId"></param>
        /// <param name="total_fee"></param>
        /// <param name="out_trade_no"></param>
        /// <returns></returns>
        public string GetNewsPayUrl(string productId, int total_fee, string out_trade_no)
        {
            //Log.Info(this.GetType().ToString(), "Native pay mode 2 url is producing...");

            WxPayData data = new WxPayData();


            data.SetValue("body", "新闻查看支付");//商品描述
            data.SetValue("attach", "融资通微信新闻查看支付");//附加数据
            //data.SetValue("out_trade_no", WxPayApi.GenerateOutTradeNo());//随机字符串
            data.SetValue("out_trade_no", out_trade_no);//商户订单号
            data.SetValue("total_fee", total_fee);//总金额
            //data.SetValue("spbill_create_ip", WxPayConfig.IP);//终端IP
            data.SetValue("time_start", DateTime.Now.ToString("yyyyMMddHHmmss"));//交易起始时间
            data.SetValue("time_expire", DateTime.Now.AddMinutes(10).ToString("yyyyMMddHHmmss"));//交易结束时间
            //data.SetValue("notify_url", WxPayConfig.NOTIFY_URL);//通知地址
            data.SetValue("goods_tag", "jjj");//商品标记
            data.SetValue("trade_type", "NATIVE");//交易类型
            data.SetValue("product_id", productId);//商品ID
            //data.SetValue("sign", data.MakeSign());//签名
            WxPayData result = WxPayApi.UnifiedOrder(data);//调用统一下单接口

            string url = result.GetValue("code_url").ToString();//获得统一下单接口返回的二维码链接

            //Log.Info(this.GetType().ToString(), "Get native pay mode 2 url : " + url);
            return url;
        }


        /// <summary>
        /// 项目查看支付获取url
        /// </summary>
        /// <param name="productId"></param>
        /// <param name="total_fee"></param>
        /// <param name="out_trade_no"></param>
        /// <returns></returns>
        public string GetXmPayUrl(string productId, int total_fee, string out_trade_no)
        {
            //Log.Info(this.GetType().ToString(), "Native pay mode 2 url is producing...");

            WxPayData data = new WxPayData();


            data.SetValue("body", "项目查看支付");//商品描述
            data.SetValue("attach", "融资通微信项目查看支付");//附加数据
            //data.SetValue("out_trade_no", WxPayApi.GenerateOutTradeNo());//随机字符串
            data.SetValue("out_trade_no", out_trade_no);//商户订单号
            data.SetValue("total_fee", total_fee);//总金额
            //data.SetValue("spbill_create_ip", WxPayConfig.IP);//终端IP
            data.SetValue("time_start", DateTime.Now.ToString("yyyyMMddHHmmss"));//交易起始时间
            data.SetValue("time_expire", DateTime.Now.AddMinutes(10).ToString("yyyyMMddHHmmss"));//交易结束时间
            //data.SetValue("notify_url", WxPayConfig.NOTIFY_URL);//通知地址
            data.SetValue("goods_tag", "jjj");//商品标记
            data.SetValue("trade_type", "NATIVE");//交易类型
            data.SetValue("product_id", productId);//商品ID
            //data.SetValue("sign", data.MakeSign());//签名
            WxPayData result = WxPayApi.UnifiedOrder(data);//调用统一下单接口

            string url = result.GetValue("code_url").ToString();//获得统一下单接口返回的二维码链接

            //Log.Info(this.GetType().ToString(), "Get native pay mode 2 url : " + url);
            return url;
        }

        /// <summary>
        /// 留言查看支付获取url
        /// </summary>
        /// <param name="productId"></param>
        /// <param name="total_fee"></param>
        /// <param name="out_trade_no"></param>
        /// <returns></returns>
        public string GetGuestBookPayUrl(string productId, int total_fee, string out_trade_no)
        {
            //Log.Info(this.GetType().ToString(), "Native pay mode 2 url is producing...");

            WxPayData data = new WxPayData();


            data.SetValue("body", "留言查看支付");//商品描述
            data.SetValue("attach", "融资通微信留言查看支付");//附加数据
            //data.SetValue("out_trade_no", WxPayApi.GenerateOutTradeNo());//随机字符串
            data.SetValue("out_trade_no", out_trade_no);//商户订单号
            data.SetValue("total_fee", total_fee);//总金额
            //data.SetValue("spbill_create_ip", WxPayConfig.IP);//终端IP
            data.SetValue("time_start", DateTime.Now.ToString("yyyyMMddHHmmss"));//交易起始时间
            data.SetValue("time_expire", DateTime.Now.AddMinutes(10).ToString("yyyyMMddHHmmss"));//交易结束时间
            //data.SetValue("notify_url", WxPayConfig.NOTIFY_URL);//通知地址
            data.SetValue("goods_tag", "jjj");//商品标记
            data.SetValue("trade_type", "NATIVE");//交易类型
            data.SetValue("product_id", productId);//商品ID
            //data.SetValue("sign", data.MakeSign());//签名
            WxPayData result = WxPayApi.UnifiedOrder(data);//调用统一下单接口

            string url = result.GetValue("code_url").ToString();//获得统一下单接口返回的二维码链接

            //Log.Info(this.GetType().ToString(), "Get native pay mode 2 url : " + url);
            return url;
        }
        /// <summary>
        /// 项目投递支付
        /// </summary>
        /// <param name="productId"></param>
        /// <param name="total_fee"></param>
        /// <param name="out_trade_no"></param>
        /// <returns></returns>
        public string GetDeliverProjectPayUrl(string productId, int total_fee, string out_trade_no)
        {
            //Log.Info(this.GetType().ToString(), "Native pay mode 2 url is producing...");

            WxPayData data = new WxPayData();


            data.SetValue("body", "项目投递支付");//商品描述
            data.SetValue("attach", "融资通微信项目投递支付");//附加数据
            //data.SetValue("out_trade_no", WxPayApi.GenerateOutTradeNo());//随机字符串
            data.SetValue("out_trade_no", out_trade_no);//商户订单号
            data.SetValue("total_fee", total_fee);//总金额
            //data.SetValue("spbill_create_ip", WxPayConfig.IP);//终端IP
            data.SetValue("time_start", DateTime.Now.ToString("yyyyMMddHHmmss"));//交易起始时间
            data.SetValue("time_expire", DateTime.Now.AddMinutes(10).ToString("yyyyMMddHHmmss"));//交易结束时间
            //data.SetValue("notify_url", WxPayConfig.NOTIFY_URL);//通知地址
            data.SetValue("goods_tag", "jjj");//商品标记
            data.SetValue("trade_type", "NATIVE");//交易类型
            data.SetValue("product_id", productId);//商品ID
            //data.SetValue("sign", data.MakeSign());//签名
            WxPayData result = WxPayApi.UnifiedOrder(data);//调用统一下单接口

            string url = result.GetValue("code_url").ToString();//获得统一下单接口返回的二维码链接

            //Log.Info(this.GetType().ToString(), "Get native pay mode 2 url : " + url);
            return url;
        }
        /**
        * 参数数组转换为url格式
        * @param map 参数名与参数值的映射表
        * @return URL字符串
        */
        private string ToUrlParams(SortedDictionary<string, object> map)
        {
            string buff = "";
            foreach (KeyValuePair<string, object> pair in map)
            {
                buff += pair.Key + "=" + pair.Value + "&";
            }
            buff = buff.Trim('&');
            return buff;
        }
    }



}
